@@ -1,7 +1,8 @@
 """HTTP exception handler middleware for FastAPI."""
 
-from fastapi import HTTPException, Request
+from fastapi import Request
 from fastapi.responses import JSONResponse, Response
+from starlette.exceptions import HTTPException as StarletteHTTPException
 
 from ..routes.response import return_response
 from ...log import footprint
@@ -9,7 +10,7 @@ from ...log import footprint
 __all__ = ("http_exception_handler",)
 
 
-async def http_exception_handler(request: Request, exc: HTTPException) -> Response:
+async def http_exception_handler(request: Request, exc: StarletteHTTPException) -> Response:
     """Handle HTTP exceptions and log them appropriately.
 
     Description:
