@@ -119,7 +119,7 @@ class Runtime:
                 footprint.leave(
                     log_type="warning",
                     message=e.message,
-                    controller=e.controller,
+                    controller=e.controller or controller,
                     subject="Request Error",
                     payload=payload,
                 )
