@@ -51,14 +51,14 @@ class Route:
         method: RouteMethod,
         handler: Callable,
         wrapping_handler: bool = True,
-        authentications: List[Auth] = None,
+        authentications: Optional[List[Auth]] = None,
         response_model: Optional[Type[BaseModel]] = None,
         default_response_model: Optional[Any] = None,
         wrapping_response_model: bool = True,
         status_code: int = 200,
-        errors: Dict[int, str] = None,
-        dependencies: List[Any] = None,
-        wrapper_kwargs: Dict[str, Any] = None,
+        errors: Optional[Dict[int, str]] = None,
+        dependencies: Optional[List[Any]] = None,
+        wrapper_kwargs: Optional[Dict[str, Any]] = None,
         name: Optional[str] = None,
         summary: Optional[str] = None,
         description: Optional[str] = None,
@@ -74,7 +74,7 @@ class Route:
         response_model_exclude_none: bool = False,
         response_model_by_alias: bool = True,
         response_return_json_directly: bool = False,
-        response_headers: Dict[int, Dict] = None,
+        response_headers: Optional[Dict[int, Dict[Any, Any]]] = None,
         response_no_cache_headers: bool = True,
     ):
         """Create a Route definition.
@@ -153,17 +153,19 @@ class Route:
 
         if wrapping_response_model:
             model_name = getattr(response_model, "__name__", "SuccessfulResponse")
+            if not isinstance(model_name, str):
+                model_name = "SuccessfulResponse"
             data_type = response_model or Any
             default_value = (
                 default_response_model if default_response_model is not None else ...
             )
-            self.response_model = create_model(
+            self.response_model = create_model(  # type: ignore[call-overload]
                 model_name,
                 __base__=SuccessResponse,
-                **{"data": (data_type, default_value)},
+                data=(data_type, default_value),
             )
         else:
-            self.response_model = response_model or SuccessResponse
+            self.response_model = response_model or SuccessResponse  # type: ignore[assignment]
 
         self.path = path
         self.method = method
@@ -213,7 +215,7 @@ class Route:
                     return return_response(
                         data=result,
                         status_code=self.status_code,
-                        response_class=self.response_class,
+                        response_class=self.response_class or JSONResponse,
                         return_json_directly=self.response_return_json_directly,
                         headers=self.response_headers,
                         no_cache=self.response_no_cache_headers,
@@ -228,7 +230,7 @@ class Route:
                     return return_response(
                         data=result,
                         status_code=self.status_code,
-                        response_class=self.response_class,
+                        response_class=self.response_class or JSONResponse,
                         return_json_directly=self.response_return_json_directly,
                         headers=self.response_headers,
                         no_cache=self.response_no_cache_headers,
