@@ -53,7 +53,7 @@ class Bucket:
         self.__secret_key = secret_key
         self.__region_name = region_name
         self.__s3_client: BaseClient = boto3.client(
-            service_name="s3",
+            "s3",
             aws_access_key_id=self.__access_key,
             aws_secret_access_key=self.__secret_key,
             endpoint_url=self.__endpoint_url if not self.__s3_mode else None,
