@@ -12,7 +12,7 @@ from typing import Any, AsyncGenerator, Generator, Optional
 from sqlalchemy import NullPool, create_engine, text
 from sqlalchemy.ext.asyncio import AsyncSession, async_sessionmaker, create_async_engine
 from sqlalchemy.orm import Session as SessionType
-from sqlalchemy.orm import declarative_base, sessionmaker
+from sqlalchemy.orm import DeclarativeBase, sessionmaker
 
 from ..core.exception import exception_to_dict
 from .config import DatabaseConfig
@@ -34,7 +34,9 @@ class DatabaseInstance:
             options for read and write connections.
     """
 
-    def __init__(self, config: DatabaseConfig) -> None:
+    base: type[DeclarativeBase]
+
+    def __init__(self, config: DatabaseConfig, base_name: Optional[str] = None) -> None:
         """Initialize DatabaseInstance with configuration settings.
 
         Args:
@@ -124,8 +126,16 @@ class DatabaseInstance:
             autoflush=False,
         )
 
-        # Declarative base for ORM models
-        self.base = declarative_base(name="Base")
+        # Create a unique declarative base for this database instance
+        if base_name is None:
+            db_name = config.get("db_name", "default")
+            base_name = f"DatabaseBase_{db_name}"
+        
+        # Create a new DatabaseBase class with isolated metadata
+        self.base = type(base_name, (DeclarativeBase,), {
+            "__module__": __name__,
+            "__doc__": f"Isolated DatabaseBase for {base_name}"
+        })
 
     def _build_async_url(self, db_url: str) -> str:
         """Convert a standard database URL to its asynchronous equivalent.
