@@ -6,7 +6,7 @@ filtering, pagination, sorting, and metadata generation capabilities.
 
 from enum import Enum
 from math import ceil
-from typing import Any, Type
+from typing import Any, Dict, List, Type
 
 from sqlalchemy import distinct as distinct_func
 from sqlalchemy import func, select
@@ -34,12 +34,12 @@ def get_list(
     options: list[Any] | None = None,
     primary_column: str = "id",
     sorting_null_at_the_end: bool = True,
-    get_function_parameters: dict[str, Any] | None = None,
     return_available_filters: bool = True,
     return_selected_filters: bool = True,
     return_rows_data: bool = True,
     export_mode: bool = False,
     return_as_dict: bool = True,
+    return_as_dict_parameters: dict[str, Any] | None = None,
     unique: bool = True,
 ) -> list[Any] | dict[str, Any]:
     """Execute a complex search query with filters, pagination, and optional
@@ -64,12 +64,12 @@ def get_list(
         options: List of SQLAlchemy query options (e.g., joinedload).
         primary_column: Name of the primary key column for deduplication.
         sorting_null_at_the_end: If True, place null values at end when sorting.
-        get_function_parameters: Parameters to pass to model's get() method.
         return_available_filters: If True, include available filter options in result.
         return_selected_filters: If True, include selected filters in result.
         return_rows_data: If True, include actual data rows in result.
         export_mode: If True, return only rows without metadata.
-        return_as_dict: If True, convert rows to dicts using model's get() method.
+        return_as_dict_parameters: Parameters to pass to model's to_dict() method.
+        return_as_dict: If True, convert rows to dicts using model's to_dict() method.
         unique: If True, deduplicate results by primary column.
 
     Returns:
@@ -80,23 +80,12 @@ def get_list(
             - selected_filters: Currently applied filters (if requested).
             - rows_data: Matching data rows (if requested).
     """
-    if joins is None:
-        joins = []
-
-    if filters is None:
-        filters = []
-
-    if searchable_columns is None:
-        searchable_columns = []
-
-    if pre_conditions is None:
-        pre_conditions = []
-
-    if options is None:
-        options = []
-
-    if get_function_parameters is None:
-        get_function_parameters = {}
+    joins = joins or []
+    filters = filters or []
+    searchable_columns = searchable_columns or []
+    pre_conditions = pre_conditions or []
+    options = options or []
+    return_as_dict_parameters = return_as_dict_parameters or {}
 
     page = current_query.get("page") or 1
     items_per_page = current_query.get("items_per_page") or 30
@@ -122,13 +111,20 @@ def get_list(
 
     # Initialize rows and conditions
     conditions = []
-    names_conditions = {filter_item.get("name"): [] for filter_item in filters}
+    names_conditions: Dict[str, List[Any]] = {
+        filter_item["name"]: [] 
+        for filter_item in filters 
+        if filter_item.get("name") is not None
+    }
 
     for filter_item in filters:
         name = filter_item.get("name")
         columns = filter_item.get("columns")
+        if not columns or not name:
+            continue
+        
         values = current_query.get(name)
-        if not columns or not name or not values:
+        if not values:
             continue
 
         target_condition = make_condition(filter_item=filter_item, values=values)
@@ -163,7 +159,7 @@ def get_list(
 
     sorting = current_query.get("sorting") or []
 
-    order_by_list = []
+    order_by_list: List[Any] = []
     if search_sort is not None:
         order_by_list.extend(search_sort)
     elif sorting := (current_query.get("sorting") or []):
@@ -209,13 +205,13 @@ def get_list(
     if return_rows_data:
         db_rows = db.execute(final_query).unique().scalars().all()
         if return_as_dict:
-            rows = [row.get(**get_function_parameters) for row in db_rows]
+            rows = [row.to_dict(**return_as_dict_parameters) for row in db_rows]  # type: ignore[attr-defined]
         else:
-            rows = db_rows
+            rows = list(db_rows)
     else:
         rows = None
 
-    if export_mode and return_rows_data:
+    if export_mode and return_rows_data and rows is not None:
         return rows
     else:
         count = db.execute(count_query).scalar_one()
@@ -229,15 +225,15 @@ def get_list(
             current_query["page"] = page
             current_query["items_per_page"] = items_per_page
 
-        result = {
+        result: Dict[str, Any] = {
             "payload": current_query,
         }
 
-        if return_rows_data:
+        if return_rows_data and rows is not None:
             result["rows_data"] = rows
 
         if return_available_filters:
-            result["available_filters"] = (
+            result["available_filters"] = (  # type: ignore[assignment]
                 get_filters_value(
                     db=db,
                     pre_conditions=pre_conditions,
@@ -250,7 +246,7 @@ def get_list(
             )
 
         if return_selected_filters:
-            result["selected_filters"] = make_selected_filters(
+            result["selected_filters"] = make_selected_filters(  # type: ignore[assignment]
                 current_query=current_query,
                 filters=filters,
             )
