@@ -34,6 +34,8 @@ def make_selected_filters(
             - type: Filter type (select, number, date, search)
     """
     selected_filters: list[dict[str, Any]] = []
+    filters = filters or []
+    current_query = current_query or {}
     for filter_item in filters:
         selected_data: dict | list | None = current_query.get(filter_item["name"])
         if not selected_data or len(selected_data) == 0:
@@ -61,6 +63,8 @@ def make_selected_filters(
                     }
                 )
         elif filter_item["type"] == "number":
+            if not isinstance(selected_data, dict):
+                continue
             minimum = selected_data.get("min")
             maximum = selected_data.get("max")
             if minimum is not None and maximum is not None:
@@ -83,6 +87,8 @@ def make_selected_filters(
                 }
             )
         elif filter_item["type"] == "date":
+            if not isinstance(selected_data, dict):
+                continue
             minimum = selected_data.get("min")
             maximum = selected_data.get("max")
             if minimum is not None and maximum is not None:
