@@ -146,7 +146,13 @@ def _should_cache(
         return True
     for cond in cache_only_for:
         col = cond.get("kwarg")
-        if cond.get("operator") == "in" and kwargs.get(col) in cond.get("value"):
+        condition_value = cond.get("value")
+        if (
+            cond.get("operator") == "in" 
+            and col is not None 
+            and condition_value is not None
+            and kwargs.get(col) in condition_value
+        ):
             return True
     return False
 
@@ -205,7 +211,8 @@ def _redis_get_sync(redis_client: Redis, key: str, controller: str) -> Optional[
         Optional[bytes]: The cached bytes value if found, or None if an error occurs.
     """
     try:
-        return redis_client.get(key)
+        result = redis_client.get(key)
+        return result if isinstance(result, (bytes, type(None))) else None
     except Exception as exception:
         footprint.leave(
             log_type="error",
@@ -234,7 +241,8 @@ async def _redis_get_async(
         Optional[bytes]: The cached bytes value if found, or None if an error occurs.
     """
     try:
-        return await asyncio.to_thread(redis_client.get, key)
+        result = await asyncio.to_thread(redis_client.get, key)
+        return result if isinstance(result, (bytes, type(None))) else None
     except Exception as exception:
         footprint.leave(
             log_type="error",
